@@ -30,10 +30,10 @@ class TestSimpleRate(unittest.TestCase):
         tarredfile = snowglobes.generate_fluence(model_path, modeltype, transformation, distance, outfile)
 
         print("Simulating detector effects with SNOwGLoBES ...")
-        snowglobes.simulate(SNOwGLoBES_path, tarredfile, detector_input=detector, detector_effects=False)
+        snowglobes.simulate(SNOwGLoBES_path, tarredfile, detector_input=detector, detector_effects=True)
 
         print("Collating results ...")
-        tables = snowglobes.collate(SNOwGLoBES_path, tarredfile, skip_plots=True, smearing=False)
+        tables = snowglobes.collate(SNOwGLoBES_path, tarredfile, skip_plots=True, smearing=True)
 
         # Use results to print the number of events in different interaction channels
         key = f"Collated_{outfile}_{detector}_events_unsmeared_weighted.dat"
@@ -48,10 +48,28 @@ class TestSimpleRate(unittest.TestCase):
         #Super-K has 32kT inner volume
         print("Total events in Super-K-like detector:" , 0.32*total_events)
 
+        # Use results to print the number of events in different interaction channels
+        # with efficiency and smearing
+        key = f"Collated_{outfile}_{detector}_events_smeared_weighted.dat"
+        total_events_smeared = 0
+        for i, channel in enumerate(tables[key]['header'].split()):
+            if i == 0:
+                continue
+            n_events = sum(tables[key]['data'][i])
+            total_events_smeared += n_events
+            print(f"{channel:10}: {n_events:.3f} events (smeared)")
+
+        #Super-K has 32kT inner volume
+        print("Total events in Super-K-like detector (with smearing):" , 0.32*total_events_smeared)
+
         # We do not use the SNOwGLoBES scaling factors but use other constants so we do not
         # expect the results to agree to 7 digits. Here sub-permille agreement is good enough.
         sk_expected = 4486.929197175579
+        sk_expected_smeared = 4044.841743901513
         sk_computed = 0.32 * total_events
+        sk_computed_smeared = 0.32 * total_events_smeared
         discrepancy = abs(sk_computed - sk_expected)/sk_expected
+        discrepancy_smeared = abs(sk_computed_smeared - sk_expected_smeared)/sk_expected_smeared
 
-        assert discrepancy < 0.001, f"Number of events computed for SK is {sk_computed}, should be {sk_expected}"
+        assert discrepancy < 0.001, f"Number of unsmeared events computed for SK is {sk_computed}, should be {sk_expected}"
+        assert discrepancy_smeared < 0.001, f"Number of smeared events computed for SK is {sk_computed_smeared}, should be {sk_expected_smeared}"
